/* Copyright (C) 2011 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.grails.datastore.gorm.simpledb.plugin.support

import org.grails.datastore.gorm.plugin.support.SpringConfigurer

import org.grails.datastore.gorm.simpledb.bean.factory.SimpleDBDatastoreFactoryBean
import org.grails.datastore.gorm.simpledb.bean.factory.SimpleDBMappingContextFactoryBean
import org.grails.datastore.mapping.transactions.DatastoreTransactionManager
import org.grails.datastore.mapping.cache.impl.TPCacheAdapterRepositoryImpl

/**
 * SimpleDB specific configuration logic for Spring
 *
 * @author Roman Stepanenko after Graeme Rocher
 * @since 1.0
 */
class SimpleDBSpringConfigurer extends SpringConfigurer {
    @Override
    String getDatastoreType() {
        return "SimpleDB"
    }

    @Override
    Closure getSpringCustomizer() {
        return {
            def simpleDBConfig = application.config?.grails?.simpledb
            def cacheAdapters = application.config?.grails?.cacheAdapters

            def theCacheAdapterRepository = new TPCacheAdapterRepositoryImpl()
            cacheAdapters?.each { clazz, adapter ->
                theCacheAdapterRepository.setTPCacheAdapter(clazz, adapter)
            }


            simpledbTransactionManager(DatastoreTransactionManager) {
                datastore = ref("simpledbDatastore")
            }

            simpledbMappingContext(SimpleDBMappingContextFactoryBean) {
                grailsApplication = ref('grailsApplication')
                pluginManager = ref('pluginManager')
            }

            simpledbDatastore(SimpleDBDatastoreFactoryBean) {
                mappingContext = ref("simpledbMappingContext")
                config = simpleDBConfig.toProperties()
                cacheAdapterRepository = theCacheAdapterRepository
            }
        }
    }
}
